changes device functions documentation according to the supported apis

Change-Id: I47ac6bbde11d54d8265e0d27ec8cd5da4d03eb8e


[ROCm/clr commit: 5f10a69ef7]
This commit is contained in:
Aditya Atluri
2017-01-20 14:19:09 -06:00
parent 100ef6d9b2
commit 5d51e1ddbd
@@ -118,7 +118,7 @@ __device__ float coshf(float x);
### cospif ### cospif
```cpp ```cpp
__device__ __host__ float cospif(float x); __device__ float cospif(float x);
``` ```
**Description:** Supported **Description:** Supported
@@ -230,7 +230,7 @@ __device__ float fdimf(float x, float y);
### fdividef ### fdividef
```cpp ```cpp
__device__ __host__ float fdividef(float x, float y); __device__ float fdividef(float x, float y);
``` ```
**Description:** Supported **Description:** Supported
@@ -302,7 +302,7 @@ __device__ float ilogbf(float x);
### isfinite ### isfinite
```cpp ```cpp
__device__ __host__ int isfinite(float a); __device__ int isfinite(float a);
``` ```
**Description:** Supported **Description:** Supported
@@ -574,7 +574,7 @@ __device__ float roundf(float x);
### rsqrtf ### rsqrtf
```cpp ```cpp
__device__ __host__ float rsqrtf(float x); __device__ float rsqrtf(float x);
``` ```
**Description:** Supported **Description:** Supported
@@ -598,7 +598,7 @@ __device__ float scalbnf(float x, int n);
### signbit ### signbit
```cpp ```cpp
__device__ __host__ unsigned signbit(float a); __device__ int signbit(float a);
``` ```
**Description:** Supported **Description:** Supported
@@ -638,7 +638,7 @@ __device__ float sinhf(float x);
### sinpif ### sinpif
```cpp ```cpp
__device__ __host__ float sinpif(float x); __device__ float sinpif(float x);
``` ```
**Description:** Supported **Description:** Supported
@@ -806,7 +806,7 @@ __device__ double cosh(double x);
### cospi ### cospi
```cpp ```cpp
__device__ __host__ double cospi(double x); __device__ double cospi(double x);
``` ```
**Description:** Supported **Description:** Supported
@@ -982,7 +982,7 @@ __device__ double ilogb(double x);
### isfinite ### isfinite
```cpp ```cpp
__device__ __host__ unsigned isfinite(double x); __device__ int isfinite(double x);
``` ```
**Description:** Supported **Description:** Supported
@@ -1270,7 +1270,7 @@ __device__ double round(double x);
### rsqrt ### rsqrt
```cpp ```cpp
__device__ __host__ double rsqrt(double x); __device__ double rsqrt(double x);
``` ```
**Description:** Supported **Description:** Supported
@@ -1294,7 +1294,7 @@ __device__ double scalbn(double x, int n);
### signbit ### signbit
```cpp ```cpp
__device__ __host__ unsigned signbit(double a); __device__ int signbit(double a);
``` ```
**Description:** Supported **Description:** Supported
@@ -1334,7 +1334,7 @@ __device__ double sinh(double x);
### sinpi ### sinpi
```cpp ```cpp
__device__ __host__ double sinpi(double x); __device__ double sinpi(double x);
``` ```
**Description:** Supported **Description:** Supported